@@ -15,7 +15,7 @@ from .formula import Formula
 Key = TypeVar("Key")
 Value = TypeVar("Value")
 
-logger = logging.Logger(__name__)
+logger = logging.getLogger(__name__)
 
 SYMBOL_SEGMENT_SEPARATOR = "_"
 
@@ -478,6 +478,7 @@ class TimeSeriesFormula(Formula, Generic[Value]):
 
             # Symbol metadata is not available, e.g. component category
             if symbol_mapping is None:
+
                 # Component data is available and up to date
                 if cache_lookup_result.entry is not None:
                     kwargs[symbol] = cache_lookup_result.entry.value
