@@ -33,6 +33,7 @@ from frequenz.channels import Bidirectional, Peekable, Receiver
 from google.protobuf.empty_pb2 import Empty  # pylint: disable=no-name-in-module
 
 from ... import microgrid
+from ..._internal.asyncio import cancel_and_await
 from ...actor._decorator import actor
 from ...microgrid import ComponentGraph
 from ...microgrid.client import MicrogridApiClient
@@ -160,16 +161,9 @@ class PowerDistributingActor:
             self.power_distributor_exponent
         )
 
-        graph = microgrid.get().component_graph
-        batteries = graph.components(component_category={ComponentCategory.BATTERY})
-
-        self._battery_pool = BatteryPoolStatus(
-            battery_ids={battery.component_id for battery in batteries},
-            max_blocking_duration_sec=30.0,
-            max_data_age_sec=10.0,
+        self._bat_inv_map, self._inv_bat_map = self._get_components_pairs(
+            microgrid.get().component_graph
         )
-
-        self._bat_inv_map, self._inv_bat_map = self._get_components_pairs(graph)
         self._battery_receivers: Dict[int, Peekable[BatteryData]] = {}
         self._inverter_receivers: Dict[int, Peekable[InverterData]] = {}
 
@@ -186,13 +180,21 @@ class PowerDistributingActor:
         self._users_channels: Dict[
             str, Bidirectional.Handle[Result, Request]
         ] = users_channels
-        self._create_users_tasks()
+        self._users_tasks = self._create_users_tasks()
         self._started = asyncio.Event()
 
-    def _create_users_tasks(self) -> None:
-        """For each user create a task to wait for request."""
+    def _create_users_tasks(self) -> List[asyncio.Task[Empty]]:
+        """For each user create a task to wait for request.
+
+        Returns:
+            List with users tasks.
+        """
+        tasks = []
         for user, handler in self._users_channels.items():
-            asyncio.create_task(self._wait_for_request(_User(user, handler)))
+            tasks.append(
+                asyncio.create_task(self._wait_for_request(_User(user, handler)))
+            )
+        return tasks
 
     def _get_upper_bound(self, batteries: Set[int]) -> int:
         """Get total upper bound of power to be set for given batteries.
@@ -242,18 +244,24 @@ class PowerDistributingActor:
         as broken for some time.
         """
         await self._create_channels()
-        await self._battery_pool.async_init()
+
         api = microgrid.get().api_client
+        battery_pool = await BatteryPoolStatus.async_new(
+            battery_ids=set(self._bat_inv_map.keys()),
+            max_blocking_duration_sec=30.0,
+            max_data_age_sec=10.0,
+        )
 
         # Wait few seconds to get data from the channels created above.
         await asyncio.sleep(self._wait_for_data_sec)
+
         self._started.set()
         while True:
             request, user = await self._request_queue.get()
 
             try:
                 pairs_data: List[InvBatPair] = self._get_components_data(
-                    request.batteries
+                    battery_pool.get_working_batteries(request.batteries)
                 )
             except KeyError as err:
                 await user.channel.send(Error(request, str(err)))
@@ -285,14 +293,10 @@ class PowerDistributingActor:
                 str(battery_distribution),
             )
 
-            tasks = await self._set_distributed_power(
+            failed_power, failed_batteries = await self._set_distributed_power(
                 api, distribution, request.request_timeout_sec
             )
 
-            failed_power, failed_batteries = self._parse_result(
-                tasks, distribution.distribution, request.request_timeout_sec
-            )
-
             if len(failed_batteries) > 0:
                 succeed_batteries = set(battery_distribution.keys()) - failed_batteries
                 response = PartialFailure(
@@ -311,7 +315,7 @@ class PowerDistributingActor:
                     excess_power=distribution.remaining_power,
                 )
 
-            self._battery_pool.update_last_request_status(response)
+            battery_pool.update_last_request_status(response)
             await user.channel.send(response)
 
     async def _set_distributed_power(
@@ -319,7 +323,7 @@ class PowerDistributingActor:
         api: MicrogridApiClient,
         distribution: DistributionResult,
         timeout_sec: float,
-    ) -> Dict[int, asyncio.Task[Empty]]:
+    ) -> Tuple[int, Set[int]]:
         """Send distributed power to the inverters.
 
         Args:
@@ -328,7 +332,8 @@ class PowerDistributingActor:
             timeout_sec: How long wait for the response
 
         Returns:
-            Dict with finished or cancelled task for each inverter.
+            Tuple where first element is total failed power, and the second element
+            set of batteries that failed.
         """
         tasks = {
             inverter_id: asyncio.create_task(api.set_power(inverter_id, power))
@@ -342,7 +347,8 @@ class PowerDistributingActor:
         )
 
         await self._cancel_tasks(pending)
-        return tasks
+
+        return self._parse_result(tasks, distribution.distribution, timeout_sec)
 
     def _check_request(self, request: Request) -> Optional[Result]:
         """Check whether the given request if correct.
@@ -530,7 +536,7 @@ class PowerDistributingActor:
         """
         pairs_data: List[InvBatPair] = []
 
-        for battery_id in self._battery_pool.get_working_batteries(batteries):
+        for battery_id in batteries:
             if battery_id not in self._battery_receivers:
                 raise KeyError(
                     f"No battery {battery_id}, "
@@ -634,3 +640,8 @@ class PowerDistributingActor:
             aws.cancel()
 
         await asyncio.gather(*tasks, return_exceptions=True)
+
+    async def _stop_actor(self) -> None:
+        """Stop all running async tasks."""
+        await asyncio.gather(*[cancel_and_await(t) for t in self._users_tasks])
+        await self._stop()  # type: ignore # pylint: disable=no-member
