@@ -10,13 +10,14 @@ import logging
 import weakref
 from collections import deque
 from datetime import datetime
+from math import isinf, isnan
 from typing import Dict, List, Optional, Set, Tuple
 from uuid import UUID, uuid4
 
 from frequenz.channels import Broadcast, Receiver
 from frequenz.channels._broadcast import Receiver as BroadcastReceiver
 
-from ...util.asyncio import cancel_and_await
+from ..._internal.asyncio import cancel_and_await
 from .. import Sample
 from ._formula_steps import (
     Adder,
@@ -125,7 +126,7 @@ class FormulaEngine:
             RuntimeError: if some samples didn't arrive, or if formula application
                 failed.
         """
-        eval_stack: List[Optional[float]] = []
+        eval_stack: List[float] = []
         ready_metrics, pending = await asyncio.wait(
             [
                 asyncio.create_task(fetcher.fetch_next(), name=name)
@@ -154,7 +155,11 @@ class FormulaEngine:
         if len(eval_stack) != 1:
             raise RuntimeError(f"Formula application failed: {self._name}")
 
-        return Sample(metric_ts, eval_stack[0])
+        res = eval_stack.pop()
+        if isnan(res) or isinf(res):
+            res = None
+
+        return Sample(metric_ts, res)
 
     async def _run(self) -> None:
         sender = self._channel.new_sender()
